translate.storage.xliff

Package translate :: Package storage :: Module xliff |
[hide private]
[frames] | no frames]

# Module xliff

source code

Module for handling XLIFF files for translation.

The official recommendation is to use the extention .xlf for XLIFF files.

Classes | [hide private]
| xliffunit A single term in the xliff file.
| xlifffile Class representing a XLIFF file store.

Imports: multistring, setXMLlang, normalize_xml_space, xml_space_ancestors, getXMLlang, string_xpath_normalized, XML_NS, string_xpath, getText, namespaced, re, xml_preserve_ancestors, normalize_space, setXMLspace, etree, MULTIWHITESPACE_RE, MULTIWHITESPACE_PATTERN, base, lisa, getXMLspace, xml_to_strelem, strelem_to_xml